@@ -195,7 +195,7 @@ cspi_init_role_table (AccessibleRole *role_table)
   return TRUE;
 }
 
-static AccessibleRole
+AccessibleRole
 cspi_role_from_spi_role (Accessibility_Role role)
 {
   /* array is sized according to IDL roles because IDL roles are the index */	
@@ -217,6 +217,21 @@ cspi_role_from_spi_role (Accessibility_Role role)
   return cspi_role; 
 }
 
+static AccessibleAttributeSet *
+cspi_attribute_set_from_sequence (const Accessibility_AttributeSet *seq)
+{
+    AccessibleAttributeSet *set = g_new0 (AccessibleAttributeSet, 1);
+    int i;
+
+    set->len = seq->_length;
+    set->attributes = g_newa (char *, set->len);
+    for (i = 0; i < set->len; ++i)
+    {
+	set->attributes[i] = g_strdup (seq->_buffer [i]);
+    }
+    return set;
+}
+
 /**
  * AccessibleRole_getName:
  * @role: an #AccessibleRole object to query.
@@ -510,6 +525,8 @@ Accessible_getRoleName (Accessible *obj)
  * This method will return useful values for roles that fall outside the
  * enumeration used in Accessible_getRole ().
  *
+ * @Since: AT-SPI 1.4
+ *
  * Returns: a UTF-8 string specifying the role of this #Accessible object.
  *
  **/
@@ -532,6 +549,8 @@ Accessible_getLocalizedRoleName (Accessible *obj)
  * Accessible_getStateSet:
  * @obj: a pointer to the #Accessible object on which to operate.
  *
+ * Gets the current state of an object.
+ *
  * Returns: a pointer to an #AccessibleStateSet representing the object's current state.
  **/
 AccessibleStateSet *
@@ -560,6 +579,58 @@ Accessible_getStateSet (Accessible *obj)
   return retval;
 }
 
+/**
+ * Accessible_getAttributes:
+ * @obj: The #Accessible being queried.
+ *
+ * Get the #AttributeSet representing any assigned 
+ * name-value pair attributes or annotations for this object.
+ * For typographic, textual, or textually-semantic attributes, see
+ * AccessibleText_getAttributes instead.
+ *
+ * Returns: The name-value-pair attributes assigned to this object.
+ */
+AccessibleAttributeSet *
+Accessible_getAttributes (Accessible *obj)
+{
+    AccessibleAttributeSet *retval;
+    Accessibility_AttributeSet *corba_seq;
+
+    cspi_return_val_if_fail (obj != NULL, NULL);
+
+    corba_seq = Accessibility_Accessible_getAttributes (
+	CSPI_OBJREF (obj), cspi_ev ());
+    cspi_return_val_if_ev ("getAttributes", NULL);
+    
+    retval = cspi_attribute_set_from_sequence (corba_seq);
+    CORBA_free (corba_seq);
+
+    return NULL;
+}
+
+/**
+ * Accessible_getHostApplication:
+ * @obj: The #Accessible being queried.
+ *
+ * Get the containing #AccessibleApplication for an object.
+ *
+ * Returns: the containing AccessibleApplication instance for this object.
+ */
+AccessibleApplication *
+Accessible_getHostApplication (Accessible *obj)
+{
+    AccessibleApplication *retval;
+
+    cspi_return_val_if_fail (obj != NULL, NULL);
+
+    retval = Accessible_getApplication (cspi_object_add (
+					    Accessibility_Accessible_getApplication (CSPI_OBJREF (obj),
+										     cspi_ev ())));
+    cspi_return_val_if_ev ("getApplication", NULL);
+
+    return retval;
+}
+
 /* Interface query methods */
 
 /**
